@@ -32,6 +32,8 @@ class MainConfig:
     # IP for CLI to access
     CLIIP = '127.0.0.1'
 
+    websocketkey = 'websocketkey'
+
     # whether or not to save CoT's to the DB
     SaveCoTToDB = bool(True)
 
@@ -39,7 +41,7 @@ class MainConfig:
     DBFilePath = str(r'/root/FTSDataBase.db')
 
     # the version information of the server (recommended to leave as default)
-    version = 'FreeTAKServer-1.3 RC 5'
+    version = 'FreeTAKServer-1.3 RC 6'
 
     ExCheckMainPath = str(Path(fr'{userpath}{python_version}/dist-packages/FreeTAKServer/ExCheck'))
 
@@ -47,7 +49,7 @@ class MainConfig:
 
     ExCheckChecklistFilePath = str(Path(fr'{userpath}{python_version}/dist-packages/FreeTAKServer/ExCheck/checklist'))
 
-    DataPackageFilePath = str(Path(fr'{userpath}{python_version}/dist-packages/FreeTAKServer/FreeTAKServerDataPackageFolde'))
+    DataPackageFilePath = str(Path(fr'{userpath}{python_version}/dist-packages/FreeTAKServer/FreeTAKServerDataPackageFolder'))
 
     # format of API message header should be {Authentication: Bearer 'TOKEN'}
 
@@ -57,13 +59,13 @@ class MainConfig:
     ConnectionMessage = f'Welcome to FreeTAKServer {version}. The Parrot is not dead. It’s just resting'
 
     #keyDir = str(r"/usr/local/lib/python3.6/dist-packages/FreeTAKServer/Certs/ServerCerts/FTS.key")
-    keyDir = str(Path(rf"{userpath}{python_version}/dist-packages/FreeTAKServer/Certs/ServerCerts/pubserver.key"))
+    keyDir = str(Path(rf"{userpath}{python_version}/dist-packages/FreeTAKServer/Certs/pubserver.key"))
 
     #pemDir = str(r"/usr/local/lib/python3.6/dist-packages/FreeTAKServer/Certs/ServerCerts/FTS.pem")
-    pemDir = str(Path(rf"{userpath}{python_version}/dist-packages/FreeTAKServer/Certs/ServerCerts/pubserver.pem")) # or crt
+    pemDir = str(Path(rf"{userpath}{python_version}/dist-packages/FreeTAKServer/Certs/pubserver.pem")) # or crt
 
-    unencryptedKey = str(Path(rf"{userpath}{python_version}/dist-packages/FreeTAKServer/Certs/ServerCerts/pubserver.key.unencrypted"))
+    unencryptedKey = str(Path(rf"{userpath}{python_version}/dist-packages/FreeTAKServer/Certs/pubserver.key.unencrypted"))
 
-    CA = str(Path(rf"{userpath}{python_version}/dist-packages/FreeTAKServer/Certs/ServerCerts/ca.pem"))
+    CA = str(Path(rf"{userpath}{python_version}/dist-packages/FreeTAKServer/Certs/ca.pem"))
 
-    password = str('atakatak')
+    password = str('your password')
