@@ -13,12 +13,14 @@ class RestAPIVariables:
         self.checkStatus = 'check_server_status'
 
     def json_vars(self):
-        self.COTSERVICE = 'CoTService'
+        self.COTSERVICE = 'TCPCoTService'
         self.DATAPACKAGESERVICE = 'TCPDataPackageService'
         self.SSLCOTSERVICE = 'SSLCoTService'
-        self.IP = 'IP'
-        self.PORT = 'PORT'
-        self.STATUS = 'STATUS'
+        self.SSLDATAPACKAGESERVICE = 'SSLDataPackageService'
+        self.RESTAPISERVICE = 'RestAPIService'
+        self.IP = 'ip'
+        self.PORT = 'port'
+        self.STATUS = 'status'
 
     def rest_methods(self):
         self.POST = 'POST'
