@@ -396,7 +396,7 @@ class FTS:
         except Exception as e:
             pass
 
-    def startup(self, CoTPort, CoTIP, DataPackagePort, DataPackageIP, RestAPIPort, RestAPIIP, SSLCoTPort, SSLCoTIP, AutoStart):
+    def startup(self, CoTPort, CoTIP, DataPackagePort, DataPackageIP, SSLDataPackagePort, SSLDataPackageIP, RestAPIPort, RestAPIIP, SSLCoTPort, SSLCoTIP, AutoStart):
         try:
             if AutoStart == 'False':
                 StartupObject = FTSObj()
@@ -414,6 +414,10 @@ class FTS:
                 StartupObject.TCPDataPackageService.TCPDataPackageServicePort = DataPackagePort
                 StartupObject.TCPDataPackageService.TCPDataPackageServiceStatus = 'start'
 
+                StartupObject.SSLDataPackageService.SSLDataPackageServiceIP = SSLDataPackageIP
+                StartupObject.SSLDataPackageService.SSLDataPackageServicePort = SSLDataPackagePort
+                StartupObject.SSLDataPackageService.SSLDataPackageServiceStatus = 'start'
+
                 StartupObject.RestAPIService.RestAPIServicePort = RestAPIPort
                 StartupObject.RestAPIService.RestAPIServiceIP = RestAPIIP
                 StartupObject.RestAPIService.RestAPIServiceStatus = 'start'
@@ -449,6 +453,10 @@ if __name__ == "__main__":
                             default=FTSObj().TCPDataPackageService.TCPDataPackageServicePort)
         parser.add_argument('-DataPackageIP', type=str, help=OrchestratorConstants().APIPORTDESC,
                             default=FTSObj().TCPDataPackageService.TCPDataPackageServiceIP)
+        parser.add_argument('-SSLDataPackagePort', type=int, help=OrchestratorConstants().APIPORTDESC,
+                            default=FTSObj().SSLDataPackageService.SSLDataPackageServicePort)
+        parser.add_argument('-SSLDataPackageIP', type=str, help=OrchestratorConstants().APIPORTDESC,
+                            default=FTSObj().SSLDataPackageService.SSLDataPackageServiceIP)
         parser.add_argument('-RestAPIPort', type=int, help=OrchestratorConstants().APIPORTDESC,
                             default=FTSObj().RestAPIService.RestAPIServicePort)
         parser.add_argument('-RestAPIIP', type=str, help=OrchestratorConstants().APIPORTDESC,
@@ -456,6 +464,6 @@ if __name__ == "__main__":
         parser.add_argument('-AutoStart', type=str, help='wether or not you want all services to start or only the root service and the RestAPI service', default='True')
         args = parser.parse_args()
         CreateStartupFilesController()
-        FTS().startup(args.CoTPort, args.CoTIP, args.DataPackagePort, args.DataPackageIP, args.RestAPIPort, args.RestAPIIP, args.SSLCoTPort, args.SSLCoTIP, args.AutoStart)
+        FTS().startup(args.CoTPort, args.CoTIP, args.DataPackagePort, args.DataPackageIP, args.SSLDataPackagePort, args.SSLDataPackageIP, args.RestAPIPort, args.RestAPIIP, args.SSLCoTPort, args.SSLCoTIP, args.AutoStart)
     except Exception as e:
         print(e)
\ No newline at end of file
