@@ -1,9 +1,11 @@
 import eventlet
-from flask import Flask, request, jsonify
+from flask import Flask, request, jsonify, session
 from flask_sqlalchemy import SQLAlchemy
 from flask_socketio import SocketIO, emit
 from flask_httpauth import HTTPTokenAuth
+from flask_login import current_user, LoginManager
 import threading
+from functools import wraps
 from lxml import etree
 from FreeTAKServer.model.FTSModel.Event import Event
 from FreeTAKServer.model.RawCoT import RawCoT
@@ -42,6 +44,8 @@ defaultValues = vars()
 defaultValues.default_values()
 
 app = Flask(__name__)
+login_manager = LoginManager()
+login_manager.init_app(app)
 auth = HTTPTokenAuth(scheme='Bearer')
 app.config['SQLALCHEMY_DATABASE_URI'] = DatabaseConfiguration().DataBaseConnectionString
 app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
@@ -64,27 +68,75 @@ def verify_token(token):
     if output:
         return output[0].Username
 
+@login_manager.user_loader
+def load_user(user_id):
+    return User.get(user_id)
+
+def socket_auth(session = None):
+    def innerfunc(x):
+        def wrapper(*args, **kwargs):
+            if hasattr(session, 'authenticated') and session.authenticated:
+                x(*args, **kwargs)
+            else:
+                pass
+        return wrapper
+    return innerfunc
+
 @app.route('/')
 def sessions():
     return b'working'
 
 @socketio.on('connect')
 def handle_message():
-    emit('data', json.dumps({'abc234': 'test123'}))
+    print('connected')
+
+@socketio.on('authenticate')
+def authenticate(token):
+    if json.loads(token)["Authenticate"] == MainConfig.websocketkey:
+        emit('authentication', json.dumps({'successful': 'True'}))
+        session.authenticated = True
+    else:
+        emit('authentication', json.dumps({'successful': 'False'}))
 
 @socketio.on('users')
+@socket_auth(session = session)
 def show_users():
-    '''import random
-    jsondata = {"Users":
-                []}
-    for user in range(random.randint(1, 100)):
-        user = {"ip": f"{random.randint(1, 255)}.{random.randint(1, 255)}.{random.randint(1, 255)}.{random.randint(1, 255)}",
-                "callsign": f"{}"}
-        jsondata["Users"].append(user)'''
+    data = [SimpleClient()]
+    data[0].callsign = ''
+    data[0].team = ''
+    data[0].ip = ''
+    returnValue = []
+    for client in data:
+        returnValue.append(ApplyFullJsonController().serialize_model_to_json(client))
+    socketio.emit('userUpdate', json.dumps(returnValue))
+    data = UpdateArray
+    for client in data:
+        returnValue.append(ApplyFullJsonController().serialize_model_to_json(client))
+    socketio.emit('userUpdate', json.dumps(returnValue))
 
 @socketio.on('logs')
+@socket_auth(session = session)
+def return_logs(time):
+    from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingConstants
+    import datetime
+    log_data = {'log_data':[]}
+    for line in reversed(open(LoggingConstants().WARNINGLOG, "r").readlines()):
+        timeoflog = line.split(" : ")[1]
+        if datetime.datetime.strptime(timeoflog, '%Y-%m-%d %H:%M:%S,%f') > datetime.datetime.strptime(json.loads(time)["time"], '%Y-%m-%d %H:%M:%S,%f'):
+            outline = {"time": '', "type": '', 'file': '', 'message': ''}
+            line_segments = line.split(" : ")
+            outline["type"] = line_segments[0]
+            outline["time"] = line_segments[1]
+            outline["file"] = line_segments[2]
+            outline["message"] = line_segments[3]
+            log_data['log_data'].append(outline)
+        else:
+            break
+    emit("logUpdate", json.dumps(log_data))
+
 
 @socketio.on('serviceInfo')
+@socket_auth(session = session)
 def show_service_info():
     import random
     import datetime as dt
@@ -117,19 +169,23 @@ def show_service_info():
         "starttime": str(starttime)
     }
 
-    emit('serviceInfo', json.dumps(jsonObject))
+    emit('serviceInfoUpdate', json.dumps(jsonObject))
 
 @socketio.on("serverHealth")
+@socket_auth(session = session)
 def serverHealth():
-    import random
+    import psutil
+    import pathlib
+    import os
     jsondata = {
-                "CPU": random.randint(1, 100),
-                "memory": random.randint(1, 100),
-                "disk": random.randint(1, 100)
+                "CPU": int(psutil.cpu_percent(interval=0.1)),
+                "memory": int(psutil.virtual_memory().percent),
+                "disk": int(psutil.disk_usage(str(pathlib.Path(os.getcwd()).anchor)).percent)
                 }
-    emit('serviceInfo', json.dumps(jsondata))
+    emit('serverHealthUpdate', json.dumps(jsondata))
 
-@app.route("/systemStatus", methods=["GET"])
+@socketio.on('systemStatus')
+@socket_auth(session=session)
 def systemStatus():
     import random
     jsondata = {
@@ -156,6 +212,7 @@ def systemStatus():
             }
         }
     }
+    emit('systemStatusUpdate', json.dumps(jsondata))
 
 @app.route("/SendGeoChat", methods=[restMethods.POST])
 def SendGeoChat():
@@ -354,8 +411,10 @@ def Clients():
         return str(e), 500
 
 @app.route('/DataPackageTable', methods=[restMethods.GET, restMethods.POST, restMethods.DELETE])
+@auth.login_required()
 def DataPackageTable():
     if request.remote_addr in MainConfig.AllowedCLIIPs:
+        from pathlib import Path
         if request.method == "GET":
             output = dbController.query_datapackage()
             for i in range(0, len(output)):
@@ -368,13 +427,41 @@ def DataPackageTable():
             return jsonify(json_list = output), 200
 
         elif request.method == "DELETE":
-            Hash = request.args.get('Hash')
-            obj = dbController.query_datapackage(f'PrimaryKey == "{Hash}"')
-            dbController.remove_datapackage(f'PrimaryKey == "{Hash}"')
-            # TODO: make this coherent with constants
-            currentPath = os.path.dirname(os.path.realpath(__file__))
-            shutil.rmtree(f'{str(currentPath)}/FreeTAKServerDataPackageFolder/{obj[0].Hash}')
+            jsondata = request.json(force=True)
+            Hashes = jsondata['DataPackages']
+            for hash in Hashes:
+                Hash = hash['hash']
+                obj = dbController.query_datapackage(f'PrimaryKey == "{Hash}"')
+                dbController.remove_datapackage(f'PrimaryKey == "{Hash}"')
+                # TODO: make this coherent with constants
+                currentPath = os.path.dirname(os.path.realpath(__file__))
+                shutil.rmtree(f'{str(currentPath)}/FreeTAKServerDataPackageFolder/{obj[0].Hash}')
             return '200', 200
+
+        elif request.method == "POST":
+            import string
+            import random
+            from pathlib import PurePath
+            from FreeTAKServer.controllers.configuration.DataPackageServerConstants import DataPackageServerConstants
+            file_dir = os.path.dirname(os.path.realpath(__file__))
+            dp_directory = PurePath(file_dir, DataPackageServerConstants().DATAPACKAGEFOLDER)
+            file_hash = request.args.get('hash')
+            app.logger.info(f"Data Package hash = {str(file_hash)}")
+            letters = string.ascii_letters
+            uid = ''.join(random.choice(letters) for i in range(4))
+            uid = 'uid-' + str(uid)
+            filename = request.args.get('filename')
+            creatorUid = request.args.get('creatorUid')
+            file = request.files.getlist('assetfile')[0]
+            directory = Path(dp_directory, file_hash)
+            if not Path.exists(directory):
+                os.mkdir(str(directory))
+            file.save(os.path.join(str(directory), filename))
+            fileSize = Path(str(directory), filename).stat().st_size
+            callsign = str(dbController.query_user(query=f'uid == "{creatorUid}"', column=['callsign']))  # fetchone() gives a tuple, so only grab the first element
+            dbController.create_datapackage(uid=uid, Name=filename, Hash=file_hash, SubmissionUser=callsign,
+                                       CreatorUid=creatorUid, Size=fileSize)
+
     else:
         return 'endpoint can only be accessed by approved IPs', 401
 
@@ -422,7 +509,8 @@ def getMission():
         "passwordProtected": random.choice(['true', 'false'])
     }
     return maincontent
-@app.route("/missionTable", methods=['GET'])
+@app.route("/MissionTable", methods=['GET'])
+@auth.login_required()
 def mission_table():
     try:
         import random
@@ -475,6 +563,7 @@ def All():
                     FTSObject.CoTService.CoTServiceStatus = CoTService.get(jsonVars.STATUS)
                 else:
                     pass
+
                 if jsonVars.DATAPACKAGESERVICE in json:
 
                     DPService = json.get(jsonVars.DATAPACKAGESERVICE)
@@ -488,6 +577,19 @@ def All():
                 else:
                     pass
 
+                if jsonVars.SSLDATAPACKAGESERVICE in json:
+
+                    DPService = json.get(jsonVars.SSLDATAPACKAGESERVICE)
+                    FTSObject.SSLDataPackageService.SSLDataPackageServiceIP = DPService.get(jsonVars.IP)
+                    try:
+                        FTSObject.SSLDataPackageService.SSLDataPackageServicePort = int(DPService.get(jsonVars.PORT))
+                    except:
+                        FTSObject.SSLDataPackageService.SSLDataPackageServicePort = ''
+                    FTSObject.SSLDataPackageService.SSLDataPackageServiceStatus = DPService.get(jsonVars.STATUS)
+
+                else:
+                    pass
+
                 if jsonVars.SSLCOTSERVICE in json:
 
                     SSLCoTservice = json[jsonVars.SSLCOTSERVICE]
@@ -501,9 +603,23 @@ def All():
                 else:
                     pass
 
-                CommandPipe.send([functionNames.Status, FTSObject])
-                out = CommandPipe.recv()
-                return '200', 200
+                if jsonVars.RESTAPISERVICE in json:
+
+                    RESTAPISERVICE = json.get(jsonVars.RESTAPISERVICE)
+                    FTSObject.RestAPIService.RestAPIServiceIP = RESTAPISERVICE.get(
+                        jsonVars.IP)
+                    try:
+                        FTSObject.RestAPIService.RestAPIServicePort = int(RESTAPISERVICE.get(jsonVars.PORT))
+                    except:
+                        FTSObject.RestAPIService.RestAPIServicePort = ''
+                    FTSObject.RestAPIService.RestAPIServiceStatus = RESTAPISERVICE.get(jsonVars.STATUS)
+
+                else:
+                    pass
+
+                    CommandPipe.send([functionNames.Status, FTSObject])
+                    out = CommandPipe.recv()
+                    return '200', 200
         else:
             return 'endpoint can only be accessed by approved IPs', 401
     except Exception as e:
@@ -514,7 +630,7 @@ def receiveUpdates():
         try:
             update = APIPipe.recv()
             global UpdateArray
-            emitUpdates(update)
+            UpdateArray.append(update)
         except Exception as e:
             print(e)
 
