@@ -1,11 +1,10 @@
-from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModel.Name import Name
 from FreeTAKServer.model.FTSModel.Uid import Uid
 from FreeTAKServer.model.FTSModel.Description import Description
 from FreeTAKServer.model.FTSModel.StartTime import StartTime
 from FreeTAKServer.model.FTSModel.CreatorUid import CreatorUid
 from FreeTAKServer.model.FTSModel.CreatorCallsign import CreatorCallsign
-class ChecklistDetails(FTSProtocolObject):
+class ChecklistDetails:
     @staticmethod
     def Checklist():
         checklistdetails = ChecklistDetails()
