@@ -5,7 +5,7 @@ class CreatorUid:
         self.INTAG = None
 
     @staticmethod
-    def CreateExCheckTemplate(INTAG=vars.CreateExCheckTemplate().INTAG, ):
+    def ExcheckUpdate(INTAG=vars.ExcheckUpdate().INTAG, ):
         creatoruid = CreatorUid()
 
         creatoruid.setINTAG(INTAG)
@@ -16,4 +16,11 @@ class CreatorUid:
         self.INTAG = INTAG
 
     def getINTAG(self):
-        return self.INTAG
\ No newline at end of file
+        return self.INTAG
+
+    @staticmethod
+    def Checklist(INTAG=vars.Checklist().INTAG):
+        creatorUid = CreatorUid()
+        creatorUid.setINTAG(INTAG)
+        return creatorUid
+
