@@ -5,7 +5,7 @@ class MissionName:
         self.INTAG = None
 
     @staticmethod
-    def CreateExCheckTemplate(INTAG=vars.CreateExCheckTemplate().INTAG, ):
+    def ExcheckUpdate(INTAG=vars.ExcheckUpdate().INTAG, ):
         missionname = MissionName()
 
         missionname.setINTAG(INTAG)
