@@ -5,7 +5,7 @@ class Size:
         self.INTAG = None
 
     @staticmethod
-    def CreateExCheckTemplate(INTAG=vars.CreateExCheckTemplate().INTAG, ):
+    def ExcheckUpdate(INTAG=vars.ExcheckUpdate().INTAG, ):
         size = Size()
 
         size.setINTAG(INTAG)
