@@ -2,4 +2,4 @@ class SSLDataPackageVariables:
     def __init__(self):
         self.SSLDataPackageIP = "0.0.0.0"
         self.SSLDataPackagePort = 8443
-        self.SSLDataPackageStatus = "start"
\ No newline at end of file
+        self.SSLDataPackageStatus = ""
\ No newline at end of file
