@@ -62,6 +62,30 @@ class RestCLIClient:
             logger.error('an exception has been thrown in CoT service startup ' + str(e))
             return -1
 
+    def start_SSL_CoT_service(self):
+        try:
+            self.SSLCoTIP = str(
+                input('enter SSL_CoT_service IP[' + str(FTS().SSLCoTService.SSLCoTServiceIP) + ']: ')) or FTS().SSLCoTService.SSLCoTServiceIP
+            self.SSLCoTPort = input('enter SSL_CoT_service Port[' + str(FTS().SSLCoTService.SSLCoTServicePort) + ']: ') or int(
+                FTS().SSLCoTService.SSLCoTServicePort)
+            self.SSLCoTPort = int(self.SSLCoTPort)
+            json_content.setdefaultSSLCoTPort(self.SSLCoTPort)
+            json_content.setdefaultSSLCoTIP(self.SSLCoTIP)
+            json_content.setdefaultSSLCoTStatus('start')
+            body = json.dumps(json_content.getJsonStatusStartAll())
+            conn = http.client.HTTPConnection(connectionIP, connectionPort)
+            conn.request("POST", "/changeStatus", body, {"Content-type": "application/json", "Accept": "text/plain"})
+            response = conn.getresponse()
+            if self.check_response(response):
+                print('CoT service started')
+            else:
+                print('CoT service startup failed')
+            return 1
+
+        except Exception as e:
+            logger.error('an exception has been thrown in CoT service startup ' + str(e))
+            return -1
+
     def stop_CoT_service(self):
         try:
             json_content.setdefaultCoTStatus('stop')
@@ -78,6 +102,22 @@ class RestCLIClient:
             logger.error("there's been an exception in the stopping of CoT Service " + str(e))
             return -1
 
+    def stop_SSL_CoT_service(self):
+        try:
+            json_content.setdefaultSSLCoTStatus('stop')
+            body = json.dumps(json_content.getJsonStatusStartAll())
+            conn = http.client.HTTPConnection(connectionIP, connectionPort)
+            conn.request("POST", "/changeStatus", body, {"Content-type": "application/json", "Accept": "text/plain"})
+            response = conn.getresponse()
+            if self.check_response(response):
+                print('CoT service stopped')
+            else:
+                print('CoT service stopping failed')
+            return 1
+        except Exception as e:
+            logger.error("there's been an exception in the stopping of CoT Service " + str(e))
+            return -1
+
     def start_data_package_service(self):
         try:
 
@@ -118,8 +158,10 @@ class RestCLIClient:
         try:
             json_content.setdefaultCoTIP(input('Please enter the CoT service IP [' + str(FTS().CoTService.CoTServiceIP) + ']: ') or FTS().CoTService.CoTServiceIP)
             json_content.setdefaultCoTPort(input('Please enter the CoT service Port [' + str(FTS().CoTService.CoTServicePort) + ']: ') or FTS().CoTService.CoTServicePort)
-            json_content.setdefaultDataPackagePort(input('Please enter the Data Package service Port [' + str(FTS().DataPackageService.DataPackageServicePort) + ']: ') or FTS().DataPackageService.DataPackageServicePort)
-            json_content.setdefaultDataPackageIP(input('Please enter the Data Package service IP [' + str(FTS().DataPackageService.DataPackageServiceIP) + ']: ') or FTS().DataPackageService.DataPackageServiceIP)
+            json_content.setdefaultDataPackagePort(input('Please enter the Data Package service Port [' + str(FTS().TCPDataPackageService.TCPDataPackageServicePort) + ']: ') or FTS().TCPDataPackageService.TCPDataPackageServicePort)
+            json_content.setdefaultDataPackageIP(input('Please enter the Data Package service IP [' + str(FTS().TCPDataPackageService.TCPDataPackageServiceIP) + ']: ') or FTS().TCPDataPackageService.TCPDataPackageServiceIP)
+            json_content.setdefaultSSLCoTIP(input('enter SSL_CoT_service IP[' + str(FTS().SSLCoTService.SSLCoTServiceIP) + ']: ') or FTS().SSLCoTService.SSLCoTServiceIP)
+            json_content.setdefaultSSLCoTPort(input('enter SSL_CoT_service Port[' + str(FTS().SSLCoTService.SSLCoTServicePort) + ']: ') or int(FTS().SSLCoTService.SSLCoTServicePort))
             body = json.dumps(json_content.getJsonStatusStartAll())
             conn = http.client.HTTPConnection(connectionIP, connectionPort)
             conn.request("POST", "/changeStatus", body, {"Content-type": "application/json", "Accept": "text/plain"})
@@ -215,7 +257,7 @@ class RestCLIClient:
             return 1
 
         except Exception as e:
-            logger.error("there has been an exception thrown in show DP function")
+            logger.error("there has been an exception thrown in show DP function " + str(e))
             return -1
 
     def remove_DP(self):
@@ -239,6 +281,8 @@ class RestCLIClient:
         print('stop_data_package_service: to begin data package service type')
         print("change_connection_info: change the address and port of the server you're connecting to")
         print('show_users: to show connected user information type')
+        print('start_federation_client_service: to begin federation with another server')
+        print('kill: to kill the full server type')
         print('kill: terminate all the services')
         print('show_DP: to show all DataPackages on the server')
         print('remove_DP: to remove a DataPackages on the server')
@@ -284,9 +328,7 @@ class RestCLIClient:
             conn.close()
             if self.check_response(data):
                 print('geochat sent')
-                return 1
             else:
-                return 1
                 print('geochat failed to send')
         except Exception as e:
             pass
@@ -301,10 +343,8 @@ class RestCLIClient:
             conn.close()
             if self.check_response(data):
                 print('geochat sent')
-                return 1
             else:
                 print('geochat failed to send')
-                return 1
         except Exception as e:
             pass
 
@@ -342,20 +382,19 @@ class RestCLIClient:
                 self.UserCommand = str(input('FTS$ ')) or 'empty'
                 try:
                     function = getattr(self, self.UserCommand)
-                    functionOutput = function()
-                    self.UserCommand = None
-                    if self.verify_output(functionOutput):
-                        pass
-                    else:
-                        raise Exception('function returned bad data')
-                except Exception as e:
-                    print('error in processing your request ' + str(e))
-            except:
-                logger.error('this is not a valid command')
+                except:
+                    logger.error('this is not a valid command')
+                functionOutput = function()
+                if self.verify_output(functionOutput):
+                    pass
+                else:
+                    raise Exception('function returned bad data')
+            except Exception as e:
+                logger.error('error in processing your request ' + str(e))
         self.stop_all()
 
 
 if __name__ == "__main__":
     from FreeTAKServer.controllers.AsciiController import AsciiController
     AsciiController().ascii()
-    RestCLIClient().receive_input()
+    RestCLIClient().receive_input()
\ No newline at end of file
